==> odata-client-microsoft-dynamics-0.1.53-sources.jar: microsoft/dynamics/crm/complex/GuidCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "Items"})
@JsonInclude(Include.NON_NULL)
public class GuidCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("Items")
    protected List<String> items;

    @JsonProperty("Items@nextLink")
    protected String itemsNextLink;

    protected GuidCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.GuidCollection";
    }

    @Property(name="Items")
    @JsonIgnore
    public CollectionPage<String> getItems() {
        return new CollectionPage<String>(contextPath, String.class, this.items, Optional.ofNullable(itemsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="Items")
    @JsonIgnore
    public CollectionPage<String> getItems(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, this.items, Optional.ofNullable(itemsNextLink), Collections.emptyList(), options);
    }

    public GuidCollection withUnmappedField(String name, String value) {
        GuidCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<String> items;
        private String itemsNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder items(List<String> items) {
            this.items = items;
            this.changedFields = changedFields.add("Items");
            return this;
        }

        public Builder items(String... items) {
            return items(Arrays.asList(items));
        }

        public Builder itemsNextLink(String itemsNextLink) {
            this.itemsNextLink = itemsNextLink;
            this.changedFields = changedFields.add("Items");
            return this;
        }

        public GuidCollection build() {
            GuidCollection _x = new GuidCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.GuidCollection";
            _x.items = items;
            _x.itemsNextLink = itemsNextLink;
            return _x;
        }
    }

    private GuidCollection _copy() {
        GuidCollection _x = new GuidCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.items = items;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("GuidCollection[");
        b.append("Items=");
        b.append(this.items);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.89-sources.jar: microsoft/dynamics/crm/complex/GuidCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.UUID;

@JsonPropertyOrder({
    "@odata.type", 
    "Items"})
@JsonInclude(Include.NON_NULL)
public class GuidCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("Items")
    protected List<UUID> items;

    @JsonProperty("Items@nextLink")
    protected String itemsNextLink;

    protected GuidCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.GuidCollection";
    }

    @Property(name="Items")
    @JsonIgnore
    public CollectionPage<UUID> getItems() {
        return new CollectionPage<UUID>(contextPath, UUID.class, this.items, Optional.ofNullable(itemsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="Items")
    @JsonIgnore
    public CollectionPage<UUID> getItems(HttpRequestOptions options) {
        return new CollectionPage<UUID>(contextPath, UUID.class, this.items, Optional.ofNullable(itemsNextLink), Collections.emptyList(), options);
    }

    public GuidCollection withUnmappedField(String name, String value) {
        GuidCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<UUID> items;
        private String itemsNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder items(List<UUID> items) {
            this.items = items;
            this.changedFields = changedFields.add("Items");
            return this;
        }

        public Builder items(UUID... items) {
            return items(Arrays.asList(items));
        }

        public Builder itemsNextLink(String itemsNextLink) {
            this.itemsNextLink = itemsNextLink;
            this.changedFields = changedFields.add("Items");
            return this;
        }

        public GuidCollection build() {
            GuidCollection _x = new GuidCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.GuidCollection";
            _x.items = items;
            _x.itemsNextLink = itemsNextLink;
            return _x;
        }
    }

    private GuidCollection _copy() {
        GuidCollection _x = new GuidCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.items = items;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("GuidCollection[");
        b.append("Items=");
        b.append(this.items);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
